@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -43,6 +43,12 @@ c'
 >>> print (n+i).get_octave_notename()
 d'
 """
+if __name__ == "__main__":
+    import sys
+    sys.path.append("src")
+    import i18n
+    i18n.setup_srcdir()
+
 import string, re
 
 class Interval:
@@ -188,4 +194,3 @@ def _test():
 
 if __name__=="__main__":
     _test()
-
