@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,6 +17,8 @@
 
 
 """
+>>> import locale, gettext
+>>> gettext.NullTranslations().install()
 >>> a = MusicalPitch.new_from_notename("g")
 >>> b = MusicalPitch.new_from_notename("f")
 >>> print a - b
@@ -34,7 +36,7 @@ ais
 >>> print MusicalPitch.new_from_notename(a.get_notename()) == a
 1
 >>> print a.clone() == a, id(a) == id(a.clone())
-1 0
+True False
 >>> a=MusicalPitch()
 >>> print a.m_octave_i == a.m_accidental_i == a.m_octave_i == 0
 1
@@ -52,11 +54,6 @@ des
 50
 >>> print MusicalPitch.new_from_int(50).get_notename()
 d
->>> import locale, gettext
->>> # Notename testing. Run setlocale to make sure we use that locale.
-...
->>> print locale.setlocale(locale.LC_ALL, "C")
-C
 >>> n=MusicalPitch.new_from_notename("fis,")
 >>> print n.get_user_octave_notename()
 f#,
@@ -65,8 +62,7 @@ f#,
 b,,
 >>> print n.get_user_octave_notename()
 b,,
->>> lang1 = gettext.translation('solfege', '/home/tom/src/solfege/share/locale/', languages=['no_NO'])
->>> lang1.install()
+>>> gettext.translation('solfege', '/home/tom/src/solfege/share/locale/', languages=['no_NO']).install()
 >>> print n.get_octave_notename()
 b,,
 >>> print n.get_user_octave_notename()
@@ -76,17 +72,16 @@ h
 >>> print _("Close")
 Lukk
 """
+if __name__ == "__main__":
+    import sys
+    sys.path.append(".")
+    sys.path.append("src")
+    import i18n
+    i18n.setup_srcdir()
+
 import types, random
 import _exceptions
 
-# We have the following to make module testing work.
-try:
-    if app_running == 'solfege':
-        pass
-except:
-    import sys; sys.path.append(".")
-    import src.i18n
-
 # The following are here so that the strings are catched by pygettext
 _("notename|c")
 _("notename|cb")
@@ -207,7 +202,7 @@ class MusicalPitch:
             notename = notename[:-2]
         try:
             self.m_notename_i = ['c', 'd', 'e', 'f', 'g', 'a', 'b'].index(notename)
-        except:
+        except ValueError:
            raise InvalidNotenameException(tmp)
     def randomize(self, lowest, highest):
         """
