@@ -32,6 +32,7 @@ import signal
 import soundcard, mpd
 import lessonfile
 import statistics
+import abstract
 import os
 import cfg, utils
 
@@ -220,12 +221,16 @@ the preferences window.
                 if not self.m_teachers.has_key(fn):
                     n = utils.exercise_name_to_module_name(fn)
                     exec("import %s" % n)
-                    self.m_teachers[fn] = locals()[n].Teacher(fn, self)
+                    if issubclass(locals()[n].Teacher, abstract.LessonbasedTeacher):
+                        self.m_teachers[fn] = locals()[n].Teacher(fn, self, lessoncollection, lessonfile, config)
+                    else:
+                        self.m_teachers[fn] = locals()[n].Teacher(fn, self, config)
                     # if we don't have a teacher, then the Gui has not been
                     # initialized either
                     self.m_ui.initialise_exercise(self.m_teachers[fn])
                     self.m_teachers[fn].g_view = self.m_ui.box_dict[fn]
-                self.m_teachers[fn].configure_exercise(lessoncollection, lessonfile, config)
+                else:
+                    self.m_teachers[fn].configure_exercise(lessoncollection, lessonfile, config)
                 self.m_ui.activate_exercise(href)
                 if not (_old_viewer == 'docviewer'
                         and self.m_running_exercise != None
