@@ -15,6 +15,17 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+__exercise_data__ = {
+    'exercise_name': 'chord',
+    'menu_path': '%s/%s' % (_("_Chords"), _("_Chords")),
+    'icon': 'graphics/chord24.png',
+    'toolbar': 0,
+    #'accel_key': gtk.keysyms.F2,
+    #'accel_mods': 0,
+}
+import exercise_setup
+exercise_setup.register_exercise(__exercise_data__)
+
 import gtk, gnome
 import gu, widgets
 import soundcard, mpd, mpd.musicdisplayer
@@ -25,6 +36,7 @@ import soundcard
 import dataparser
 
 class Teacher(abstract.LessonbasedTeacher):
+    exercise_data = __exercise_data__
     OK = 0
     ERR_PICKY = 1
     # valid values for self.q_status:
@@ -34,8 +46,9 @@ class Teacher(abstract.LessonbasedTeacher):
     # QSTATUS_GIVE_UP  after 'Give Up' has been pressed.
     CORRECT = 1
     ALL_CORRECT = 2
-    def __init__(self, exname, app):
-        abstract.LessonbasedTeacher.__init__(self, exname, app)
+    def __init__(self, exname, app, lesson_collection, lesson_file, config):
+        abstract.LessonbasedTeacher.__init__(self, exname, app,
+              lesson_collection, lesson_file, config)
         self.lessonfileclass = lessonfile.ChordLessonfile
         try: # the lessonfile might contain errors.
             self.parse_lessonfile()
@@ -184,23 +197,8 @@ class Gui(abstract.LessonbasedGui):
         # config_box #
         ##############
         self.config_box.set_spacing(gnome.ui.PAD_SMALL)
-        self.g_lessonfile_selector = widgets.SelectLessonfileWidget(
-            self.m_t, self.g_win, self.update_gui_after_lessonfile_change)
-        self.g_lessonfile_selector.show()
-        self.config_box.pack_start(self.g_lessonfile_selector)
-
-        hbox = gu.bHBox(self.config_box)
-        label = gtk.Label(_("Random transpose:"))
-        label.show()
-        hbox.pack_start(label)
-        self.g_random_transpose = gtk.Entry()
-        self.g_random_transpose.set_editable(False)
-        self.g_random_transpose.show()
-        hbox.pack_start(self.g_random_transpose)
-
-        button = gtk.Button(_("Change ..."))
-        button.show()
-        hbox.pack_start(button)
+        self.add_select_lessonfile_gui()
+        self.add_random_transpose_gui()
 
         self.g_instrument_configurator  \
               = widgets.InstrumentConfigurator(self.m_exname, 3)
@@ -246,6 +244,7 @@ class Gui(abstract.LessonbasedGui):
         self.g_music_displayer.clear()
         if self.m_t.m_P:
             self.g_new.set_sensitive(True)
+            self.g_random_transpose.set_text(str(self.m_t.m_P.header.random_transpose))
         else:
             self.g_new.set_sensitive(False)
         self.g_repeat.set_sensitive(False)
