@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# GNU Solfege - eartraining for GNOME
+# GNU Solfege - ear training for GNOME
 # Copyright (C) 2000, 2001  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
@@ -21,8 +21,7 @@ if __name__ == '__main__':
     pygtk.require("2.0")
     import sys
     sys.path.append('src')
-    if 'gtkhtml' in sys.argv:
-        import gtkhtml2
+    import gtkhtml2
 
 
 import sys
@@ -39,6 +38,8 @@ import configureoutput
 import cfg
 
 class _HtmlWidgetCommon(object):
+    def __init__(self):
+        self.m_document_wd = None
     def on_key_press_event(self, *argv):
         """
         Will be used to implement scrolling when HTML is available
@@ -52,10 +53,10 @@ class _HtmlWidgetCommon(object):
             languages = i18n.langs()
         for lang in languages:
             if os.path.isfile(os.path.join('online-docs', lang, filename)):
-                os.chdir(os.path.join("online-docs", lang))
-                self.source(open(filename, 'r').read())
+                head, tail = os.path.split(filename)
+                self.m_document_wd = os.path.join("online-docs", lang, head)
+                self.source(open(os.path.join("online-docs", lang, filename), 'r').read())
                 filefound = 1
-                os.chdir("../..")
                 break
         if not filefound:
             for lang in languages:
@@ -73,9 +74,10 @@ class Font:
             self.m_size, self.m_italic, self.m_bold, self.m_teletype = f[0][0]
 
 class HTMLWriter(formatter.NullWriter):
-    def __init__(self, html, activate_cb, anchor_track_cb):
+    def __init__(self, html, textviewhtmlwidget, activate_cb, anchor_track_cb):
         formatter.NullWriter.__init__(self)
         self.g_tw = html
+        self.g_textviewhtmlwidget = textviewhtmlwidget
         self.activate_cb = activate_cb
         self.anchor_track_cb = anchor_track_cb
         self.m_font = Font(None)
@@ -85,8 +87,8 @@ class HTMLWriter(formatter.NullWriter):
         self.m_charset="ascii"
         self.m_link_list = []
         self.m_table = None
-        self._para_is_new = 0
         self.m_ignore_flowing_data = 0
+        self._para_is_new = None
         self.setup_fonts()
         self.g_tw.connect('button-release-event', self.on_button_release)
     def on_button_release(self, view, event):
@@ -113,7 +115,7 @@ class HTMLWriter(formatter.NullWriter):
         #self.send_paragraph(1)
         self.send_line_break()
         self.m_table = 1
-        self.m_td_string = ""
+        self.m_td_list = []
         buf = self.g_tw.get_buffer()
         it = buf.get_end_iter()
         a = buf.create_child_anchor(it)
@@ -124,19 +126,26 @@ class HTMLWriter(formatter.NullWriter):
         self.g_tw.add_child_at_anchor(self.g_table_table, a)
         self.m_tableidx = [0, 0]
     def end_td(self):
-        l = gtk.Label(self.m_td_string)
-        l.set_use_markup(1)
-        l.set_alignment(0.0, 0.5)
-        l.show()
-        self.g_table_table.attach(l, self.m_tableidx[0], self.m_tableidx[0]+1, self.m_tableidx[1], self.m_tableidx[1]+1)
-        self.m_td_string = ""
-        pass
+        hbox = gtk.HBox()
+        hbox.show()
+        self.g_table_table.attach(hbox, self.m_tableidx[0], self.m_tableidx[0]+1, self.m_tableidx[1], self.m_tableidx[1]+1)
+        for ctype, data in self.m_td_list:
+            if ctype == 'text':
+                l = gtk.Label(data)
+                l.set_use_markup(1)
+                l.set_alignment(0.0, 0.5)
+                l.show()
+                hbox.pack_start(l, False)
+            elif ctype == 'image':
+                hbox.pack_start(data, False)
+        self.m_td_list = []
     def send_flowing_data(self, txt):
         if self.m_ignore_flowing_data:
             return
         buf = self.g_tw.get_buffer()
-        if not isinstance(txt, unicode):
-           txt = txt.decode(self.m_charset, 'replace')
+        # FIXME the whole charset/unicode stuff need revision
+        if self.m_charset == "UTF-8":
+            txt = unicode(txt, self.m_charset, 'replace')
         txt = txt.strip('\n')
         tags = ['normal', '%s-margin%i' % self.m_margin]
         if self.m_link:
@@ -147,7 +156,7 @@ class HTMLWriter(formatter.NullWriter):
             self._para_is_new = 0
         if self.m_label_data:
             if self.m_label_data == '*':
-                txt = unichr(0x25CF) + " " + txt
+                txt = unichr(0x2022) + " " + txt
             else:
                 txt = self.m_label_data + " " + txt
             tags.append('li')
@@ -167,9 +176,11 @@ class HTMLWriter(formatter.NullWriter):
                     txt = "<i>%s</i>" % txt
                 if t == 'tt':
                     txt = "<tt>%s</tt>" % txt
-            self.m_td_string += txt
-            return
-        apply(buf.insert_with_tags_by_name, [buf.get_end_iter(), txt]+ tags)
+                if self.m_link:
+                    txt = '<span color="blue" underline="single">%s</span>' % txt
+            self.m_td_list.append(('text', txt))
+        else:
+            apply(buf.insert_with_tags_by_name, [buf.get_end_iter(), txt]+ tags)
         self.m_label_data = None
     def on_anchor_event(self, eventbox, event, addr):
         if event.type == gtk.gdk.ENTER_NOTIFY:
@@ -192,12 +203,15 @@ class HTMLWriter(formatter.NullWriter):
         buf.insert(buf.get_end_iter(), "\n"+"-"*90+"\n")
     def do_img(self, src, alt):
         im = gtk.Image()
-        im.set_from_file(src)
+        im.set_from_file(os.path.join(self.g_textviewhtmlwidget.m_document_wd, src))
         im.show()
-        buf = self.g_tw.get_buffer()
-        anchor = buf.create_child_anchor(buf.get_end_iter())
-        self.g_tw.add_child_at_anchor(im, anchor)
-        #self.send_line_break()
+        if self.m_table:
+            self.m_td_list.append(['image', im])
+        else:
+            buf = self.g_tw.get_buffer()
+            anchor = buf.create_child_anchor(buf.get_end_iter())
+            self.g_tw.add_child_at_anchor(im, anchor)
+            #self.send_line_break()
     def setup_fonts(self):
         b = self.g_tw.get_buffer()
         t = b.create_tag('normal')
@@ -235,10 +249,6 @@ class HTMLWriter(formatter.NullWriter):
             t = b.create_tag('ul-margin%i' % n)
             t.set_property('left-margin', n*20+10)
 
-        for n in range(10):#FIXME numeric constant
-            t = b.create_tag('ol-margin%i' % n)
-            t.set_property('left-margin', n*20+10)
-
 
 class MyHTMLParser(htmllib.HTMLParser):
     def __init__(self, formatter, writer):
@@ -319,9 +329,10 @@ class MyHTMLParser(htmllib.HTMLParser):
 class TextViewHtmlWidget(gtk.ScrolledWindow, _HtmlWidgetCommon):
     def __init__(self, activate_cb, anchor_track_cb):
         gtk.ScrolledWindow.__init__(self)
+        _HtmlWidgetCommon.__init__(self)
         self.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
         self.g_tw = gtk.TextView()
-        self.writer = HTMLWriter(self.g_tw, activate_cb, anchor_track_cb)
+        self.writer = HTMLWriter(self.g_tw, self, activate_cb, anchor_track_cb)
         self.formatter = formatter.AbstractFormatter(self.writer)
         self.parser = MyHTMLParser(self.formatter, self.writer)
         self.g_tw.set_editable(0)
@@ -344,6 +355,7 @@ class TextViewHtmlWidget(gtk.ScrolledWindow, _HtmlWidgetCommon):
 class GtkHtml2Widget(gtk.ScrolledWindow, _HtmlWidgetCommon):
     def __init__(self, activate_cb, anchor_track_cb):
         gtk.ScrolledWindow.__init__(self)
+        _HtmlWidgetCommon.__init__(self)
         self.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
         self.activate_cb = activate_cb
         self.anchor_track_cb = anchor_track_cb
@@ -360,36 +372,29 @@ class GtkHtml2Widget(gtk.ScrolledWindow, _HtmlWidgetCommon):
             self.g_view.connect('on-url', lambda f, url: self.anchor_track_cb(url))
         self.grab_focus = self.g_view.grab_focus
     def on_request_url(self, document, url, stream):
+        """This function is called by the gtkhtml2 widget when it needs to
+        load additional urls to display a file. For example images on the
+        page.
+        """
         #if url == "style.css":
         #    stream.set_mime_type("text/css")
         #    print stream.get_mime_type()
-        s = open(url, 'r').read()
-        stream.write(s)
+        try:
+            s = open(os.path.join(self.m_document_wd, url), 'r').read()
+            stream.write(s)
+        except IOError:
+            if url.endswith('.png'):
+                s = open('graphics/image-not-found.png').read()
+                stream.write(s)
+            else:
+                print >> sys.stderr, "Not found:", filename
     def source(self, html):
         self.g_document.clear()
         self.g_document.open_stream("text/html")
         self.g_document.write_stream(html)
         self.g_document.close_stream()
 
-def _test():
-    import gettext
-    gettext.install('solfege', 'share/locale', unicode=1)
-    sys.path.insert(0, ".")
-    import gtk
-    w = gtk.Window()
-    w.set_size_request(300, 400)
-    def activate_cb(*v):
-        print "ACTIVATE_CB", v
-    def anchor_track_cb(*v):
-        print "ANCHOR_TRACK_CB", v
-    if 'textview' in sys.argv:
-        h = TextViewHtmlWidget(activate_cb, anchor_track_cb)
-    elif 'gtkhtml' in sys.argv:
-        h = GtkHtml2Widget(activate_cb, anchor_track_cb)
-    else:
-        h = HtmlWidget(activate_cb, anchor_track_cb)
-    s = """
-<html>
+s = """<html>
 <head>
 <style type="text/css">
 h1 { font-weight: bold; font-size: 2em;    margin: 0.67em 0 0;}
@@ -605,12 +610,42 @@ En <a href=" "> link </a> her
 </body></html>
 
 """
-    if sys.argv[-1:][0].endswith('.html'):
-        s = file(sys.argv[-1:][0]).read()
-    h.source(s)
-    w.add(h)
-    w.show_all()
-    w.connect('destroy', gtk.mainquit)
+
+def _test():
+    import gettext
+    gettext.install('solfege', 'share/locale', unicode=1)
+    sys.path.insert(0, ".")
+    import gtk
+    class TestWin(gtk.Window):
+        def __init__(self):
+            gtk.Window.__init__(self)
+            self.set_size_request(700, 400)
+            self.g_html1 = TextViewHtmlWidget(self.activate_cb, self.anchor_track_cb)
+            self.g_html2 = GtkHtml2Widget(self.activate_cb, self.anchor_track_cb)
+            self.m_filename = sys.argv[-1:][0]
+            print "filename", self.m_filename
+            if sys.argv[-1:][0].endswith('.html'):
+                s = file(sys.argv[-1:][0]).read()
+                self.g_html1.source(s)
+                self.g_html2.source(s)
+            vbox = gtk.VBox()
+            self.add(vbox)
+            button = gtk.Button("Reload")
+            button.connect('clicked', self.on_reload)
+            vbox.pack_start(button, False)
+            vbox.pack_start(self.g_html1)
+            vbox.pack_start(self.g_html2)
+            self.show_all()
+            self.connect('destroy', gtk.mainquit)
+        def on_reload(self, btn):
+            s = file(self.m_filename, 'r').read()
+            self.g_html1.source(s)
+            self.g_html2.source(s)
+        def activate_cb(self, *v):
+            print "ACTIVATE_CB", v
+        def anchor_track_cb(self, *v):
+            print "ANCHOR_TRACK_CB", v
+    w = TestWin()
     gtk.mainloop()
 
 if configureoutput.WITH_GTKHTML:
@@ -620,6 +655,7 @@ else:
     HtmlWidget = TextViewHtmlWidget
 
 if __name__ == '__main__':
+    gtk.rc_parse("solfege.gtkrc")
     _test()
 
 
