@@ -16,6 +16,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import sys, os, time, random
+import types
 
 # i18n should be imported very early in program init because it setup
 # the _ and _i functions for the whole program.
@@ -123,14 +124,14 @@ class SplashWin(gtk.Window):
     def show_progress(self, txt):
         self.g_infolabel.set_text(txt)
         while gtk.events_pending():
-            gtk.mainiteration(0)
+            gtk.main_iteration(0)
 
 if not filter(lambda a: a in sys.argv, ['--no-splash', '--usage', '-?', '--gtk-help']):
     splash_win = SplashWin()
     time.sleep(0.1)
     gtk.gdk.flush()
     while gtk.events_pending():
-        gtk.mainiteration(0)
+        gtk.main_iteration(0)
 else:
     splash_win = None
     if '--no-splash' in sys.argv:
@@ -171,10 +172,29 @@ import soundcard
 import mpd, mpd.musicdisplayer, gu, cfg
 
 
-import chord, chordvoicing, harmonicinterval, melodicinterval, \
+# The order the modules are imported affect the ordering in the menus.
+import melodicinterval, chord, rhythm
+import chordvoicing, harmonicinterval, \
        singinterval, idbyname, dictation, twelvetone, \
-       idtone, compareintervals, singchord, rhythm, identifybpm, \
-       harmonicprogressiondictation
+       idtone, compareintervals, singchord, identifybpm, \
+       harmonicprogressiondictation, singanswer,\
+       polyrhythm, intervals
+
+import exercise_setup
+exercise_setup.register_exercise({
+    'exercise_name': 'id-by-name',
+    'exercise_config': 'solfege/scales',
+    'menu_path': '%s/%s' % (_("_Misc exercises"), _("_Scales")),
+    'toolbar': 4.5,
+    'icon': 'graphics/identifyscale24.png',
+})
+exercise_setup.register_exercise({
+    'exercise_name': 'id-by-name',
+    'exercise_config': 'solfege/scales-thirds',
+    'menu_path': '%s/%s' % (_("_Misc exercises"), _("Scales in t_hirds")),
+    'icon': 'graphics/identifyscale24.png',
+})
+
 
 class DocViewer(gtk.VBox):
     def __init__(self, activate_cb):
@@ -218,7 +238,7 @@ class MusicViewerWindow(gtk.Dialog):
     def __init__(self, app):
         gtk.Dialog.__init__(self)
         self.m_app = app
-        self.set_size_request(400, 200)
+        self.set_default_size(400, 200)
         self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer(utils.play_tone)
         self.vbox.pack_start(self.g_music_displayer)
         b = gu.bButton(self.action_area, _("Close"), self.m_app.close_musicviewer)
@@ -398,69 +418,66 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
             menubar.add(menuitem)
             menuitem.set_submenu(func(ag))
         self.g_menubar.show_all()
+    def create_submenu(self, data, ag):
+        """FIXME rename
+        """
+        menu = gtk.Menu()
+        for d in data:
+            menuitem = gtk.ImageMenuItem(d['menu_path'].split('/')[1])
+            if d.has_key('icon'):
+                im = gtk.Image()
+                im.set_from_file(d['icon'])
+                im.set_from_pixbuf(im.get_pixbuf().scale_simple(16, 16, gtk.gdk.INTERP_TILES))
+                menuitem.set_image(im)
+            if d.has_key('exercise_config'):
+                s = 'solfege:practise/%s/%s' % (d['exercise_name'], d['exercise_config'])
+            else:
+                s = 'solfege:practise/%s' % d['exercise_name']
+            menuitem.connect('activate', lambda o, self=self, s=s: self.m_app.handle_href(s))
+            if d.has_key('accel_key'):
+                menuitem.add_accelerator('activate', ag, d['accel_key'], d['accel_mods'], gtk.ACCEL_VISIBLE)
+            menu.add(menuitem)
+        return menu
     def create_ex_menu(self, exlist, ag):
+        """
+        Each item in exlist:
+        (MENUTEXT, URI, graphics/FILENAME.PNG)
+        The icon is optional.
+        """
         menu = gtk.Menu()
         for ex in exlist:
-            if type(ex) == type(""):
-                if const.exercisedata[ex][1]:
-                    item = gtk.ImageMenuItem(const.exercisedata[ex][0])
-                    im = gtk.Image()
-                    im.set_from_file(os.path.join('graphics', const.exercisedata[ex][1]))
-                    im.set_from_pixbuf(im.get_pixbuf().scale_simple(16, 16, gtk.gdk.INTERP_TILES))
-                    item.set_image(im)
-                else:
-                    item = gtk.MenuItem(const.exercisedata[ex][0])
-                if const.exercisedata[ex][2]:
-                    item.add_accelerator('activate', ag, const.exercisedata[ex][2], const.exercisedata[ex][3], gtk.ACCEL_VISIBLE)
-                if len(const.exercisedata[ex]) >= 5:
-                    item.connect('activate', lambda o, self=self, ex=ex: self.m_app.handle_href(const.exercisedata[ex][4]))
-                else:
-                    item.connect('activate', lambda o, self=self, ex=ex: self.m_app.handle_href('solfege:practise/'+ex))
-                menu.add(item)
+            if ex[0] == ex[1] == 'SEP':
+                item = gtk.SeparatorMenuItem()
             else:
                 item = gtk.ImageMenuItem(ex[0])
                 item.connect('activate', lambda o, url=ex[1]: self.m_app.handle_href(url))
-		if len(ex) > 2:
+                if len(ex) > 2:
                     im = gtk.Image()
                     im.set_from_file(os.path.join('graphics', ex[2]))
                     im.set_from_pixbuf(im.get_pixbuf().scale_simple(16, 16, gtk.gdk.INTERP_TILES))
                     item.set_image(im)
-                menu.add(item)
+            menu.add(item)
         return menu
+    def get_file_menu_data(self):
+        menus = {}
+        sections = []
+        for rec in __exdata__:
+            m, n = rec['menu_path'].split("/")
+            if not menus.has_key(m):
+                menus[m] = []
+                sections.append(m)
+            menus[m].append(rec)
+        return sections, menus
     def create_file_menu(self, ag):
         menu = gtk.Menu()
         if self.get_bool("gui/menus_have_tearoff"):
             item = gtk.TearoffMenuItem()
             menu.add(item)
-        ##
-        menuitem = gtk.MenuItem(_("_Intervals"))
-        menu.add(menuitem)
-        menuitem.set_submenu(self.create_ex_menu(('harmonic-interval',
-                                                  'melodic-interval',
-                                                  'sing-interval',
-                                                  'compare-intervals'), ag))
-        ##
-        menuitem = gtk.MenuItem(_("_Chords"))
-        menu.add(menuitem)
-        menuitem.set_submenu(self.create_ex_menu(('chord',
-                                                  'chord-voicing',
-                                                  'sing-chord'), ag))
-        ##
-        menuitem = gtk.MenuItem(_("_Rhythm"))
-        menu.add(menuitem)
-        menuitem.set_submenu(self.create_ex_menu(('rhythm',
-                                                  'identify-bpm'), ag))
-        ##
-        menuitem = gtk.MenuItem(_("_Misc exercises"))
-        menu.add(menuitem)
-        menuitem.set_submenu(self.create_ex_menu((
-             (_("_Scales"), 'solfege:/id-by-name/solfege/scales', 'identifyscale24.png'),
-             (_("Scales in t_hirds"), 'solfege:/id-by-name/solfege/scales-thirds', 'identifyscale24.png'),
-                                                  'id-by-name',
-                                                  'dictation',
-                                                  'twelve-tone',
-                                                  'id-tone',
-                                                  'harmonic-progression-dictation'), ag))
+        sections, d = self.get_file_menu_data()
+        for k in sections:
+            menuitem = gtk.MenuItem(k)
+            menu.add(menuitem)
+            menuitem.set_submenu(self.create_submenu(d[k], ag))
         ##
         menuitem = gtk.MenuItem(_("_Theory"))
         menu.add(menuitem)
@@ -600,15 +617,24 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
             self.get_dock_item_by_name("navbar").hide()
         # main toolbar
         self.g_toolbar =  gtk.Toolbar()
-        for ex in const.exercises:
+        exdict = {}
+        tblist_ordered = []
+        tblist_unordered = []
+        for e in __exdata__:
+            exdict[e['exercise_name']] = e
+            if e.has_key('toolbar'):
+                if type(e['toolbar']) == types.BooleanType and e['toolbar'] == True:
+                    tblist_unordered.append(e)
+                else:
+                    tblist_ordered.append(e)
+        tblist_ordered.sort(lambda a, b: cmp(a['toolbar'], b['toolbar']))
+        for ex in tblist_ordered + tblist_unordered:
             im = gtk.Image()
-            im.set_from_file(os.path.join('graphics', const.exercisedata[ex][1]))
-            n = string.replace(const.exercisedata[ex][0], '_', '')
-            button = self.g_toolbar.append_item(n, None, None, im, None, None)
-            if len(const.exercisedata[ex]) >= 5:
-                button.connect('clicked', lambda button, ex=ex: self.m_app.handle_href(const.exercisedata[ex][4]))
-            else:
-                button.connect('clicked', lambda button, ex=ex: self.m_app.handle_href("solfege:practice/"+ex))
+            if not ex.has_key('toolbar'):
+                continue
+            im.set_from_file(ex['icon'])
+            button = self.g_toolbar.append_item(ex['exercise_pretty_name'], None, None, im, None, None)
+            button.connect('clicked', lambda button, ex=ex: self.m_app.handle_href("solfege:practice/"+ex['exercise_name']+'/'+ex['exercise_config']))
         self.add_toolbar(self.g_toolbar, "toolbar", "normal", "top", 1, 0, 1)
         s = self.get_string('gui/toolbar_style')
         if not (s in ('icons', 'text', 'both')):
@@ -665,5 +691,5 @@ w.show()
 if splash_win:
     splash_win.destroy()
 w.post_constructor()
-gtk.mainloop()
+gtk.main()
 
