@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -33,8 +33,8 @@ class IntervalCheckBox(gtk.HBox, cfg.ConfigUtils):
             self.checkbox_dict[x] = c = gtk.ToggleButton(const.short_interval_name[x])
             c.set_data('interval', x)
             if x in intervals:
-                c.set_active(gtk.TRUE)
-            c.connect('clicked', self.on_toggle)
+                c.set_active(True)
+            c.connect('toggled', self.on_toggle)
             c.show()
             self.pack_start(c)
         self.add_watch(self.m_varname, self._watch_cb)
@@ -66,32 +66,32 @@ class MultipleIntervalConfigWidget(gtk.VBox, cfg.ConfigUtils):
         self._watched_interval_id = None
         self._watched_interval = None
         self.m_ignore_iclick = 0
-        box = gu.bHBox(self, expand=gtk.FALSE)
+        box = gu.bHBox(self, expand=False)
         box.set_spacing(gnome.ui.PAD_SMALL)
-        box.pack_start(gtk.Label(_("Number of intervals:")), gtk.FALSE)
+        box.pack_start(gtk.Label(_("Number of intervals:")), False)
         self.g_num_int_spin = gu.nSpinButton(self.m_exname,
                        'number_of_intervals',
                        gtk.Adjustment(1, 1, self.MAX_INT, 1, 10))
         self.add_watch('number_of_intervals', self.on_num_int_spin)
-        box.pack_start(self.g_num_int_spin, gtk.FALSE)
+        box.pack_start(self.g_num_int_spin, False)
         self.g_all_int_button = gu.bButton(box,
                   _("Configure all intervals in this exercise like this"),
-                  self.configure_all_like_active_interval, expand=gtk.FALSE)
+                  self.configure_all_like_active_interval, expand=False)
         self.add_watch('number_of_intervals', lambda n, self=self: \
                self.g_all_int_button.set_sensitive(self.get_int(n)!=1))
 
-        box = gu.bHBox(self, expand=gtk.FALSE)
+        box = gu.bHBox(self, expand=False)
         box.set_spacing(gnome.ui.PAD_SMALL)
         box.pack_start(gtk.Label(
-                _("Togglebuttons is for interval number:")), gtk.FALSE)
+                _("Togglebuttons is for interval number:")), False)
         self.m_int_sel_adjustment \
              = gtk.Adjustment(1, 1, self.get_int('number_of_intervals'), 1)
         self.g_int_sel_spin = gu.nSpinButton(self.m_exname,
                   'cur_edit_interval', self.m_int_sel_adjustment, digits=0)
         self.g_int_sel_spin.connect('changed', self.on_int_sel_spin)
-        box.pack_start(self.g_int_sel_spin, gtk.FALSE)
+        box.pack_start(self.g_int_sel_spin, False)
         table = gtk.Table()
-        self.pack_start(table, gtk.FALSE)
+        self.pack_start(table, False)
 
         label = gtk.Label(_("Up:"))
         label.set_alignment(1.0, 0.5)
@@ -103,12 +103,12 @@ class MultipleIntervalConfigWidget(gtk.VBox, cfg.ConfigUtils):
             self.g_interval_chk[x] = c = gtk.ToggleButton(const.short_interval_name[x])
             c.set_data('interval', x)
             if x in V:
-                c.set_active(gtk.TRUE)
+                c.set_active(True)
             c.show()
             c.connect('clicked', self.on_interval_chk_clicked)
             table.attach(c, x, x+1, 0, 1)
 
-        box = gu.bHBox(self, expand=gtk.FALSE)
+        box = gu.bHBox(self, expand=False)
         label = gtk.Label(_("Down:"))
         label.set_alignment(1.0, 0.5)
         table.attach(label, 0, 1, 1, 2, xpadding=gnome.ui.PAD_SMALL)
@@ -118,15 +118,15 @@ class MultipleIntervalConfigWidget(gtk.VBox, cfg.ConfigUtils):
             self.g_interval_chk[x] = c = gtk.ToggleButton(const.short_interval_name[-x])
             c.set_data('interval', x)
             if x in V:
-                c.set_active(gtk.TRUE)
+                c.set_active(True)
             c.show()
             c.connect('clicked', self.on_interval_chk_clicked)
             table.attach(c, -x, -x+1, 1, 2)
         table.show_all()
         if self.g_num_int_spin.get_value_as_int() == 1:
-            self.g_all_int_button.set_sensitive(gtk.FALSE)
+            self.g_all_int_button.set_sensitive(False)
         gu.bButton(self, _("Reset to default values"), self.reset_to_default,
-                  gtk.FALSE, gtk.FALSE)
+                  False, False)
         self._watch_interval(self.get_int('cur_edit_interval')-1)
     def reset_to_default(self, _o):
         self.set_int('cur_edit_interval', 1)
