@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,7 +26,6 @@ if __name__ == '__main__':
 
 import gtk
 import mpd, gu, cfg
-import types
 import gobject
 
 # FIXME This was not defined in gtk-types.defs yet
@@ -44,12 +43,12 @@ class NotenameSpinButton(gtk.HBox):
         e = gtk.EventBox()
         e.set_name("NotenameSpinButtonLabel")
         frame.add(e)
-        self.pack_start(frame, gtk.FALSE)
+        self.pack_start(frame, False)
         self.g_label.set_size_request(60, -1)#FIXME hardcoded value
         frame.set_shadow_type(gtk.SHADOW_IN)
         e.add(self.g_label)
         vbox = gtk.VBox()
-        self.pack_start(vbox, gtk.FALSE)
+        self.pack_start(vbox, False)
         # up
         self.g_up = gtk.Arrow(gtk.ARROW_UP, gtk.SHADOW_OUT)
         eb1 = gtk.EventBox()
@@ -128,46 +127,6 @@ gobject.signal_new('value-changed', NotenameSpinButton,
                    (gobject.TYPE_PYOBJECT,))
 
 
-class OLDNotenameSpinButton(gtk.SpinButton):
-    def __init__(self, default_value):
-        #FIXME values are _BROKEN_SPIN too large to workaround problem with
-        # spinbutton and input/output signals.
-        #adj = gtk.Adjustment(mpd.notename_to_int(default_value)+_BROKEN_SPIN, 1.0+_BROKEN_SPIN, 127.0+_BROKEN_SPIN, 1.0, 12.0, 0.0)
-        adj = gtk.Adjustment(mpd.notename_to_int(default_value), 1.0, 127.0, 1.0, 12.0, 0.0)
-        gtk.SpinButton.__init__(self, adj,  0, 0)
-        self.set_update_policy(gtk.UPDATE_IF_VALID)
-        self.connect('input', self.on_input_signal)
-        self.connect('output', self.on_output_signal)
-        self.__tmpval = 1.0
-    def on_input_signal(self, spin, cob):
-        try:# test if the text field is a valid notename
-            mpd.notename_to_int(spin.get_text())
-            return gtk.TRUE
-        except:
-            return INPUT_ERROR
-    def Xon_input_signal(self, spin, cob):#FIXME old workaround. broken by pygtk 1.99.14 or .15
-        valid_notename = None
-        try:
-            i = mpd.notename_to_int(spin.get_text())
-            spin.set_value(i+_BROKEN_SPIN)
-            return gtk.TRUE
-        except:
-            return INPUT_ERROR
-    def on_output_signal(self, spin):
-        if self.get_value() - int(self.get_value()) > 0.001:
-            spin.set_value(self.__tmpval)
-            return gtk.TRUE
-        if spin.get_text() != mpd.int_to_user_notename(spin.get_value_as_int()):
-            spin.set_text(mpd.int_to_user_notename(spin.get_value_as_int()))
-            self.__tmpval = spin.get_value_as_int()
-        return gtk.TRUE
-    def Xon_output_signal(self, spin):
-        n = spin.get_value_as_int()
-        if _BROKEN_SPIN <= n <= 127 + _BROKEN_SPIN:
-            if spin.get_text() != mpd.int_to_notename(n-_BROKEN_SPIN):
-                self.set_text(mpd.int_to_notename(n-_BROKEN_SPIN))
-        return gtk.TRUE
-
 class NotenameRangeController(object):
     def __init__(self, spin_low, spin_high, lowest_value, highest_value):
         self.g_spin_low = spin_low
@@ -219,7 +178,7 @@ def _test():
     #####
     ns  = NotenameSpinButton("cis''")
     ns.show()
-    vbox.pack_start(ns, gtk.FALSE)
+    vbox.pack_start(ns, False)
     #####
     adj = gtk.Adjustment(mpd.notename_to_int('c'), 1.0, 127.0, 1.0, 12.0, 0.0)
     n = NotenameSpinButton("d'")
