@@ -15,6 +15,18 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+__exercise_data__ = {
+    'exercise_name': 'polyrhythm',
+    'menu_path': '%s/%s' % (_("_Junk"), _("_Polyrhythm")),
+    #'icon': 'graphics/chord24.png',
+    #'toolbar': 0,
+    #'accel_key': gtk.keysyms.F2,
+    #'accel_mods': 0,
+}
+import exercise_setup
+exercise_setup.register_exercise(__exercise_data__)
+
+
 import gtk, gnome
 import gu, widgets
 import soundcard, mpd
@@ -22,8 +34,9 @@ import abstract, const
 import random, string
 
 class Teacher(abstract.Teacher):
-    def __init__(self, exname, app):
-        abstract.Teacher.__init__(self, exname, app)
+    exercise_data = __exercise_data__
+    def __init__(self, exname, app, config):
+        abstract.Teacher.__init__(self, exname, app, config)
         self.m_timeout = None
     def timeout_x_y(self, x, y, bpm):
         A = 60; B = 61
